pub enum LabelType {
Action,
CommandPolicy,
CommandRecall,
CommandSeal,
CommandOpen,
Temporary,
Function,
}Expand description
Types of Labels
Variants
Action
This label represents the entry point of an action
CommandPolicy
This label represents the entry point of a command policy block
CommandRecall
This label represents the entry point of a command recall block
CommandSeal
A command seal block
CommandOpen
A command open block
Temporary
This label is a temporary destination for implementing branching constructs.
Function
Function entry point