Crate aranya_policy_module

Crate aranya_policy_module 

Policy Module

Defines core data types for compiled modules.

Re-exports

pub use aranya_policy_ast as ast;

Modules

ffi
Data definitions used by the FFI interface
named
NamedMap and associated traits and types.

Macros

arg
Shorthand for creating Args.

Structs

ActionDef
An action definition.
ActionDefResolver
The resolver for an archived ActionDef
ArchivedActionDef
An archived ActionDef
ArchivedAttribute
An archived Attribute
ArchivedCodeMap
An archived CodeMap
ArchivedCommandDef
An archived CommandDef
ArchivedConstStruct
An archived ConstStruct
ArchivedField
An archived Field
ArchivedLabel
An archived Label
ArchivedModule
An archived Module
ArchivedModuleV0
An archived ModuleV0
Attribute
A command attribute.
AttributeResolver
The resolver for an archived Attribute
CodeMap
The code map contains the original source and can map VM instructions to text ranges inside that source.
CodeMapResolver
The resolver for an archived CodeMap
CommandDef
A command definition.
CommandDefResolver
The resolver for an archived CommandDef
ConstStruct
A Struct value
ConstStructResolver
The resolver for an archived ConstStruct
Field
A struct or command field.
FieldResolver
The resolver for an archived Field
Label
Labels are branch targets and execution entry points.
LabelResolver
The resolver for an archived Label
Module
The serializable state of a Machine.
ModuleResolver
The resolver for an archived Module
ModuleV0
The Version 0 module format
ModuleV0Resolver
The resolver for an archived ModuleV0
RangeError
An error for a range that doesn’t exist. Used in CodeMap.
SpannedText
This is a simplified version of Pest’s Span. We can’t use Pest’s version because we need to work in no_std environments.
UnsupportedVersion
Unsupported Module version.

Enums

ArchivedConstValue
An archived ConstValue
ArchivedExitReason
An archived ExitReason
ArchivedInstruction
An archived Instruction
ArchivedLabelType
An archived LabelType
ArchivedMeta
An archived Meta
ArchivedModuleData
An archived ModuleData
ArchivedTarget
An archived Target
ArchivedWrapType
An archived WrapType
ConstValue
A constant or literal value used in policy.
ConstValueResolver
The resolver for an archived ConstValue
ExitReason
Reason for ending execution.
ExitReasonResolver
The resolver for an archived ExitReason
Instruction
The machine instruction types
InstructionResolver
The resolver for an archived Instruction
LabelType
Types of Labels
LabelTypeResolver
The resolver for an archived LabelType
Meta
Compiler Tracer metadata
MetaResolver
The resolver for an archived Meta
ModuleData
Versioned Module data.
ModuleDataResolver
The resolver for an archived ModuleData
Target
The target of a branch
TargetResolver
The resolver for an archived Target
Version
Identifies a Module.
WrapType
Type of Value wrapping
WrapTypeResolver
The resolver for an archived WrapType