pub enum ValueConversionError {
InvalidType {
want: String,
got: String,
msg: String,
},
InvalidStructMember(Identifier),
OutOfRange,
BadState,
}Expand description
Indicates that the Value conversion has failed
Variants
InvalidType
A conversion was attempted to a type that is not compatible with this Value
InvalidStructMember(Identifier)
A struct conversion found a field mismatch between types
OutOfRange
The target type does not have sufficient range to represent this Value
BadState
Some internal state is corrupt
Implementations